GetStorageUtil class

Constructors

GetStorageUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getStorage ↔ GetStorage?
getter/setter pair

Static Methods

getStorageBool(String key) bool
getStorageDouble(String key) double
getStorageInteger(String key) int
getStorageList(String key) List
getStorageString(String key) String
setStorage() → dynamic
setStorageBool(String key, bool value) → dynamic
setStorageDouble(String key, double value) → dynamic
setStorageInteger(String key, int value) → dynamic
setStorageList(String key, List value) → dynamic
setStorageString(String key, String value) → dynamic