KBAdsViews class

Constructors

KBAdsViews()

Properties

bannerAdNotifier ValueNotifier<BannerAd?>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bannerAd() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showNoItemsFound(dynamic height, dynamic message) Widget